@@ -151,7 +151,7 @@ examples = [
 for example in examples:
     ints = EinsumSpec.string_to_ints(example[0])
     rusty = Einsum.from_einsum_string(
-        example[0], [ScalarConstant(1, tuple([example[1][i] for i in ints_here])) for ints_here in ints[0]]
+        example[0], *[ScalarConstant(1, tuple([example[1][i] for i in ints_here])) for ints_here in ints[0]]
     )
     with catchtime("rust"):
         optimized = einsum_nest_optimize(rusty)
