@@ -1655,6 +1655,7 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
 #[pyfunction]
 pub fn einsum_permute_to_rearrange(einsum: &Einsum) -> Option<Rearrange> {
     if einsum.args.len() == 1
+        && einsum.out_axes.len() > 0
         && einsum.args[0].1.len() == einsum.out_axes.len()
         && is_unique(&einsum.out_axes)
         && is_unique(&einsum.args[0].1)
@@ -1664,8 +1665,9 @@ pub fn einsum_permute_to_rearrange(einsum: &Einsum) -> Option<Rearrange> {
             RearrangeSpec {
                 input_ints: einsum.args[0].1.iter().map(|z| sv![*z]).collect(),
                 output_ints: einsum.out_axes.iter().map(|z| sv![*z]).collect(),
-                int_sizes: sv![OpSize::NONE;einsum.info().rank()],
-            },
+                int_sizes: sv![OpSize::NONE;(*einsum.out_axes.iter().max().unwrap()+1) as usize],
+            }
+            .canonicalize(false),
             einsum.name_cloned(),
         ));
     }
