@@ -6,6 +6,7 @@ use crate::pyo3_prelude::*;
 use crate::util::AxisInt;
 use crate::{
     cached_lambda,
+    eq_by_big_hash::EqByBigHash,
     py_types::{PyShape, Tensor},
     rearrange_spec::{OpSize, RearrangeSpec},
     tensor_util::{
@@ -47,7 +48,6 @@ pub mod algebraic_rewrite;
 pub mod batching;
 pub mod canonicalize;
 pub mod circuit_manipulation;
-pub mod circuit_matchers;
 pub mod circuit_optimizer;
 pub mod circuit_utils;
 pub mod compiler_heuristics;
@@ -61,6 +61,7 @@ pub mod deep_rewrite;
 pub mod diag_rewrite;
 pub mod generalfunction;
 pub mod generalfunction_rewrite;
+pub mod get_update;
 pub mod module_nodes;
 pub mod module_rewrite;
 pub mod named_axes;
@@ -505,6 +506,12 @@ pub trait CircuitNodeAutoName: CircuitNode {
     fn auto_name(&self, name: Option<String>) -> Option<String>;
 }
 
+impl<T: CircuitNode> EqByBigHash for T {
+    fn hash(&self) -> HashBytes {
+        self.info().hash
+    }
+}
+
 pub trait CircuitNodeDefer: CircuitNodeInit {
     fn as_trait_obj(&self) -> &dyn CircuitNode;
     fn map_children_enumerate_impl<F, E>(&self, f: F) -> Result<Self, CircuitConstructionError>
@@ -526,14 +533,7 @@ pub trait CircuitNodeUnion {
 #[macro_export]
 macro_rules! circuit_node_eq_ord {
     ($type_name:ty) => {
-        impl ::std::cmp::PartialEq for $type_name {
-            fn eq(&self, other: &Self) -> bool {
-                use $crate::circuit::prelude::*;
-                self.info().hash == other.info().hash
-            }
-        }
-
-        impl ::std::cmp::Eq for $type_name {}
+        $crate::impl_eq_by_big_hash!($type_name);
 
         impl ::std::cmp::Ord for $type_name {
             fn cmp(&self, other: &Self) -> ::std::cmp::Ordering {
@@ -548,21 +548,9 @@ macro_rules! circuit_node_eq_ord {
                 Some(::std::cmp::Ord::cmp(self, other))
             }
         }
-
-        impl ::std::hash::Hash for $type_name {
-            fn hash<H: ::std::hash::Hasher>(&self, state: &mut H) {
-                state.write(&self.info().hash[..::std::mem::size_of::<u64>()]);
-            }
-        }
     };
 }
 
-pub trait UnwrapToOption {
-    type Item;
-
-    fn try_unwrap(self) -> Option<Self::Item>;
-}
-
 // this is what peak rust development looks like
 #[doc(hidden)]
 #[macro_export]
@@ -584,7 +572,7 @@ macro_rules! define_circuit_union_impl {
         }
 
         paste::paste! {
-            #[derive(::std::fmt::Debug, ::std::clone::Clone, Copy, Eq, PartialEq, Hash)]
+            #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash, PartialOrd, Ord)]
             pub enum [<$name Type>] {
                 $(
                     $x,
@@ -1861,11 +1849,7 @@ impl PyCircuitBase {
     }
 
     fn __hash__(&self) -> u64 {
-        u64::from_le_bytes(
-            self.info().hash[..std::mem::size_of::<u64>()]
-                .try_into()
-                .unwrap(),
-        )
+        self.first_u64()
     }
 
     pub fn self_flops(&self) -> BigUint {
