@@ -42,12 +42,14 @@ use crate::pyo3_prelude::*;
 pub mod all_imports;
 mod caching;
 pub mod circuit;
+pub mod eq_by_big_hash;
 pub mod hashmaps;
 pub mod lazy;
 mod lru_cache;
 pub mod opt_einsum;
 pub mod py_types;
 pub mod python_callables;
+pub mod python_wrapped;
 pub mod rearrange_spec;
 pub mod rrfs;
 mod server;
@@ -144,8 +146,13 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_class::<circuit::DiscreteVar>()?;
     m.add_class::<circuit::StoredCumulantVar>()?;
     m.add_class::<circuit::Cumulant>()?;
-    m.add_class::<circuit::circuit_matchers::Matcher>()?;
-    m.add_class::<circuit::circuit_matchers::RegexMatcher>()?;
+    m.add_class::<circuit::get_update::Matcher>()?;
+    m.add_class::<circuit::get_update::matcher::RegexWrap>()?;
+    m.add_class::<circuit::get_update::IterativeMatcher>()?;
+    m.add_class::<circuit::get_update::IterateMatchResults>()?;
+    m.add_class::<circuit::get_update::Transform>()?;
+    m.add_class::<circuit::get_update::Updator>()?;
+    m.add_class::<circuit::get_update::Getter>()?;
 
     m.add_class::<lru_cache::TensorCacheRrfs>()?;
 
