@@ -518,7 +518,19 @@ impl RearrangeSpec {
         format!("{:?}", self)
     }
     pub fn shapes(&self) -> Result<(Shape, Shape), TensorInvariantError> {
-        if self.int_sizes.iter().any(|x| x.is_none()) {
+        let used_ints: HashSet<u8> = self
+            .input_ints
+            .iter()
+            .chain(&self.output_ints)
+            .flatten()
+            .cloned()
+            .collect();
+        if self
+            .int_sizes
+            .iter()
+            .enumerate()
+            .any(|(i, x)| x.is_none() && used_ints.contains(&(i as u8)))
+        {
             return Err(TensorInvariantError::RearrangeHasWildcardSizes { spec: self.clone() });
         }
         Ok((
