@@ -28,9 +28,3 @@ pub fn circuit_server_serve(my_url: String, device: String, tensor_cache: Option
         request.respond(response).unwrap();
     }
 }
-
-// #[test]
-// #[ignore]
-fn run_server() {
-    circuit_server_serve("0.0.0.0:9876".to_owned(), "cpu".to_owned(), None)
-}
