@@ -5,8 +5,7 @@ use crate::{
 use macro_rules_attribute::apply;
 use once_cell::sync::Lazy;
 
-use std::fmt::Debug;
-use std::hash::Hash;
+use std::{fmt::Debug, hash::Hash, mem};
 pub type AxisInt = u8;
 
 /// letters used in einsum and rearrange strings
@@ -339,3 +338,82 @@ macro_rules! ss {
         Some($s.to_owned())
     };
 }
+
+trait FromCollect<ItemNew>: FromIterator<ItemNew> {
+    fn from_collect(x: impl IntoIterator<Item = impl Into<ItemNew>>) -> Self;
+}
+
+impl<ItemNew, T: FromIterator<ItemNew>> FromCollect<ItemNew> for T {
+    fn from_collect(x: impl IntoIterator<Item = impl Into<ItemNew>>) -> Self {
+        x.into_iter().map(Into::into).collect()
+    }
+}
+
+pub trait IterInto<Item>: IntoIterator<Item = Item> {
+    fn into_collect<ItemNew, B: FromIterator<ItemNew>>(self) -> B
+    where
+        Item: Into<ItemNew>;
+
+    fn into_iter_into<ItemNew>(
+        self,
+    ) -> std::iter::Map<<Self as IntoIterator>::IntoIter, fn(Item) -> ItemNew>
+    where
+        Item: Into<ItemNew>;
+}
+
+impl<Item, T: IntoIterator<Item = Item>> IterInto<Item> for T {
+    fn into_collect<ItemNew, B: FromIterator<ItemNew>>(self) -> B
+    where
+        Item: Into<ItemNew>,
+    {
+        self.into_iter_into().collect()
+    }
+
+    fn into_iter_into<ItemNew>(
+        self,
+    ) -> std::iter::Map<<Self as IntoIterator>::IntoIter, fn(Item) -> ItemNew>
+    where
+        Item: Into<ItemNew>,
+    {
+        self.into_iter().map(Into::into)
+    }
+}
+
+pub enum EmptySingleMany<T> {
+    Empty,
+    Single(T),
+    Many(Vec<T>),
+}
+
+impl<T> EmptySingleMany<T> {
+    pub fn new(mut x: Vec<T>) -> Self {
+        if x.is_empty() {
+            Self::Empty
+        } else if x.len() == 1 {
+            Self::Single(x.pop().unwrap().into())
+        } else {
+            Self::Many(x)
+        }
+    }
+}
+
+impl<T> From<Vec<T>> for EmptySingleMany<T> {
+    fn from(x: Vec<T>) -> Self {
+        EmptySingleMany::new(x)
+    }
+}
+
+pub fn split_first_take<T: Default>(x: &mut [T]) -> Option<(T, impl Iterator<Item = T> + '_)> {
+    x.split_first_mut()
+        .map(|(l, r)| (mem::take(l), r.into_iter().map(mem::take)))
+}
+
+pub fn flip_op_result<T, E>(x: Option<Result<T, E>>) -> Result<Option<T>, E> {
+    x.map_or(Ok(None), |x| x.map(Some))
+}
+
+pub fn as_sorted<Item: Ord>(x: impl IntoIterator<Item = Item>) -> Vec<Item> {
+    let mut out: Vec<_> = x.into_iter().collect();
+    out.sort();
+    out
+}
